import { interfaces } from 'inversify';
import { Feature } from '@common-stack/server-core';
import { TaggedType } from '@common-stack/core';

import {preferences} from './preferences';
import { TYPES } from './constants';
import { IOutputService } from './interfaces';
import { resolver, schema } from './graphql';
import { outputModule, outputModuleMicroservice } from './container';

const outputServiceGen = (container: interfaces.Container) => {
    const environment = container.get('Environment');
    if (environment === 'development') {
        return { outputService: container.get<IOutputService>(TYPES.IOutputService)};
    } else {
        return { outputService: container.getNamed<IOutputService>(TYPES.IOutputService, TaggedType.MICROSERVICE) };
    }
};

export default new Feature({
    schema,
    createResolversFunc: resolver,
    createPreference: preferences,
    createServiceFunc: outputServiceGen,
    createContainerFunc: [outputModule, outputModuleMicroservice],
} as any);
